wk-20230109

FALSE 0001445305--12-31 0001445305 2023-01-09 2023-01-09
UNITED STATES
SECURITIES AND EXCHANGE COMMISSION
Washington, D.C. 20549
___________________________________
FORM 8-K
___________________________________
CURRENT REPORT
Pursuant to Section 13 or 15(d)
of the Securities Exchange Act of 1934
January 9, 2023
Date of Report (Date of earliest event reported)
___________________________________
WORKIVA INC.
(Exact name of registrant as specified in its charter)
___________________________________

Delaware (State or other jurisdiction of incorporation or organization) | 001-36773 (Commission File Number) | 47-2509828 (I.R.S. Employer Identification Number)
2900 University Blvd Ames, IA 50010 (888) 275-3125
(Address of principal executive offices and zip code)
(888) 275-3125
(Registrant's telephone number, including area code)
___________________________________

Check the appropriate box below if the Form 8-K filing is intended to simultaneously satisfy the filing obligation of the registrant under any of the following provisions:

☐ | Written communications pursuant to Rule 425 under the Securities Act (17 CFR 230.425)
☐ | Soliciting material pursuant to Rule 14a-12 under the Exchange Act (17 CFR 240.14a-12)
☐ | Pre-commencement communications pursuant to Rule 14d-2(b) under the Exchange Act (17 CFR 240.14d-2(b))
☐ | Pre-commencement communications pursuant to Rule 13e-4(c) under the Exchange Act (17 CFR 240.13e-4(c))

Securities registered pursuant to Section 12(b) of the Act:
Title of each class | Trading Symbol | Name of each exchange on which registered
Class A common stock, par value $.001 | WK | New York Stock Exchange

Indicate by check mark whether the registrant is an emerging growth company as defined in Rule 12b-2 of the Exchange Act.
Emerging growth company ☐
If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 13(a) of the Exchange Act. ¨

Section 5 - Corporate Governance and Management
Item 5.03 Amendments to Articles of Incorporation or Bylaws; Change in Fiscal Year.
On January 9, 2023, the Board of Directors of Workiva Inc. (the "Company") amended and restated the Company's bylaws (as amended, the “Bylaws”) to clarify and enhance procedural mechanics in connection with stockholder nominations of directors, including by requiring a stockholder directly or indirectly soliciting proxies from other stockholders to use a proxy card color other than white.
Clean and marked versions of the Bylaws are attached hereto as Exhibits 3.1(a) and (b) and are hereby incorporated by reference into this Item 5.03. The foregoing summary description of the Amended and Restated Bylaws is qualified in its entirety by reference to the full text of the Bylaws.
Section 9 - Financial Statements and Exhibits
Item 9.01 - Financial Statements and Exhibits
(d): The following exhibits are being filed herewith:

Exhibit Number |  | Description
3.1(a) |  | Bylaws of Workiva Inc., as amended January 9, 2023 (clean)
3.1(b) |  | Bylaws of Workiva Inc., as amended January 9, 2023 (marked)
104 |  | Cover Page Interactive Data File (embedded within the Inline XBRL document)

SIGNATURE
Pursuant to the requirements of the Securities Exchange Act of 1934, as amended, the Registrant has duly caused this report to be signed on its behalf by the undersigned hereunto duly authorized on this 10th day of January, 2023.

WORKIVA INC.
By: | /s/ Brandon Ziegler
Name: | Brandon Ziegler
Title: | Executive Vice President, Chief Legal Officer and Secretary